## 📝 Description / 描述
Fixes # (issue number)

## 🛠️ Type of Change / 修改类型
- [ ] 🐛 Bug fix (non-breaking change which fixes an issue) / Bug 修复
- [ ] ✨ New feature (non-breaking change which adds functionality) / 新功能
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected) / 重大变更（破坏性修改）
- [ ] 📝 Documentation update / 文档更新
- [ ] ⚡ Performance improvement / 性能优化

## ✅ Checklist / 检查清单
- [ ] I have performed a self-review of my own code / 我已完成代码自检
- [ ] I have run `uv run ruff format .` / 我已运行 Ruff 格式化
- [ ] I have run `uv run ruff check --fix .` / 我已运行 Ruff 修复 Lint
- [ ] My changes generate no new warnings / 我的修改没有产生新的警告
- [ ] I have added tests that prove my fix is effective or that my feature works / 我已添加相关测试
- [ ] New and existing unit tests pass locally with my changes / 本地所有测试均已通过